@@ -15,6 +15,9 @@ class Command(BaseCommand):
         # Initial data
         self.stdout.write("Creating fixtures...")
         call_command('loaddata', 'modes')
+        call_command('loaddata', 'operators')
+        call_command('loaddata', 'satelliteidentifiers')
+        call_command('loaddata', 'satelliteentries')
         call_command('loaddata', 'satellites')
         call_command('loaddata', 'transmitters')
         call_command('loaddata', 'telemetries')
