@@ -31,10 +31,10 @@ SERVICE_TYPE = [
     'Space Operation', 'Space Research', 'Standard Frequency and Time Signal', 'Unknown'
 ]
 COORDINATION_STATUS = [
-    'ITU Requested', 'ITU Rejected', 'ITU Coordinated', 'IARU Requested', 'IARU Rejected',
+    'ITU Requested', 'ITU Rejected', 'ITU Coordinated', 'IARU Requested', 'IARU Declined',
     'IARU Coordinated', 'Uncoordinated'
 ]
-BAD_COORDINATIONS = ['ITU Rejected', 'IARU Rejected', 'Uncoordinated']  # 'violations'
+BAD_COORDINATIONS = ['ITU Rejected', 'IARU Declined', 'Uncoordinated']  # 'violations'
 URL_REGEX = r"(?:http(s)?:\/\/)?[\w.-]+(?:\.[\w\.-]+)+[\w\-\._~:/?#[\]@!\$&'\(\)\*\+,;=.]+$"
 MIN_FREQ = 0
 MAX_FREQ = 40000000000
@@ -375,7 +375,7 @@ class Satellite(models.Model):
         :returns: bool
         """
         bad_transmitter_count = 0
-        for transmitter in Transmitter.objects.filter(satellite=self.id):
+        for transmitter in Transmitter.objects.filter(satellite=self.id).exclude(status='invalid'):
             if transmitter.bad_transmitter:
                 bad_transmitter_count += 1
         return bad_transmitter_count > 0
