@@ -10,6 +10,7 @@ from celery import shared_task
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.sites.models import Site
+from django.core.cache import cache
 from django.core.exceptions import ValidationError
 from django.core.files import File
 from django.core.mail import send_mail
@@ -30,6 +31,12 @@ LOGGER = logging.getLogger('db')
 CONTEXT = zmq.Context()
 
 
+def delay_task_with_lock(task, lock_id, lock_expiration, *args):
+    """Ensure unique run of a task by aquiring lock"""
+    if cache.add('{0}-{1}'.format(task.name, lock_id), '', lock_expiration):
+        task.delay(*args)
+
+
 @shared_task
 def check_celery():
     """Dummy celery task to check that everything runs smoothly."""
