@@ -279,7 +279,7 @@ class PopulatedDBTest(TestCase):
         # refresh statistics first
         refresh = self.client.get('/statistics/')
         response = self.client.get('/stats/')
-        assertContains(response, 'Total Satellites')
+        assertContains(response, 'calculation')
 
 
 def test_robots(client):
