@@ -4,13 +4,14 @@ For local installation settings please copy .env-dist to .env and edit
 the appropriate settings in that file. You should not need to edit this
 file for local settings!
 """
+from pathlib import Path
+
 import sentry_sdk
 from decouple import Csv, config
 from dj_database_url import parse as db_url
 from sentry_sdk.integrations.celery import CeleryIntegration
 from sentry_sdk.integrations.django import DjangoIntegration
 from sentry_sdk.integrations.redis import RedisIntegration
-from unipath import Path
 
 from db import __version__
 
@@ -31,14 +32,13 @@ DJANGO_APPS = (
     'django.contrib.admin',
 )
 THIRD_PARTY_APPS = (
-    'avatar',
     'bootstrap_modal_forms',
     'rest_framework',
     'rest_framework.authtoken',
     'drf_spectacular',
     'django_countries',
     'django_filters',
-    'fontawesome_5',
+    'fontawesomefree',
     'widget_tweaks',
     'allauth',
     'allauth.account',
@@ -100,16 +100,17 @@ SERVER_EMAIL = DEFAULT_FROM_EMAIL
 CACHES = {
     'default': {
         'BACKEND': config(
-            'CACHE_BACKEND', default='django.core.cache.backends.locmem.LocMemCache'
+            'CACHE_BACKEND',
+            default='django.core.cache.backends.locmem.LocMemCache',
         ),
         'LOCATION': config('CACHE_LOCATION', default='unique-location'),
-        'OPTIONS': {
-            'MAX_ENTRIES': 5000,
-            'CLIENT_CLASS': config('CACHE_CLIENT_CLASS', default=''),
-        },
         'KEY_PREFIX': 'db-{0}'.format(ENVIRONMENT),
     }
 }
+
+if CACHES['default']['BACKEND'] == 'django.core.cache.backends.locmem.LocMemCache':
+    CACHES['default']['OPTIONS'] = {'MAX_ENTRIES': 5000}
+
 CACHE_TTL = config('CACHE_TTL', default=300, cast=int)
 
 # Internationalization
@@ -125,7 +126,7 @@ TEMPLATES = [
     {
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
         'DIRS': [
-            Path(ROOT).child('templates').resolve(),
+            Path(ROOT).joinpath('templates').resolve(),
         ],
         'OPTIONS': {
             'context_processors': [
@@ -158,7 +159,7 @@ TEMPLATES = [
 STATIC_ROOT = config('STATIC_ROOT', default=Path('staticfiles').resolve())
 STATIC_URL = config('STATIC_URL', default='/static/')
 STATICFILES_DIRS = [
-    Path(ROOT).child('static').resolve(),
+    Path(ROOT).joinpath('static').resolve(),
 ]
 STATICFILES_FINDERS = (
     'django.contrib.staticfiles.finders.FileSystemFinder',
@@ -178,12 +179,14 @@ COMPRESS_FILTERS = {
     'css': [
         'compressor.filters.css_default.CssAbsoluteFilter',
         'compressor.filters.cssmin.rCSSMinFilter'
-    ]
+    ],
+    'js': ['compressor.filters.jsmin.JSMinFilter']
 }
 
 # App conf
 ROOT_URLCONF = 'db.urls'
 WSGI_APPLICATION = 'db.wsgi.application'
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
 
 # Auth
 AUTHENTICATION_BACKENDS = ('django.contrib.auth.backends.ModelBackend', )
@@ -386,9 +389,17 @@ SPECTACULAR_SETTINGS = {
 # Security
 SECRET_KEY = config('SECRET_KEY', default='changeme')
 SECURE_HSTS_SECONDS = config('SECURE_HSTS_SECONDS', default=31536000, cast=int)
+SECURE_HSTS_INCLUDE_SUBDOMAINS = True
+SECURE_CONTENT_TYPE_NOSNIFF = True
+SECURE_BROWSER_XSS_FILTER = True
+SECURE_PROXY_SSL_HEADER = config(
+    'SECURE_PROXY_SSL_HEADER', default='', cast=Csv(post_process=tuple)
+) or None
+ALLOWED_HOSTS = config('ALLOWED_HOSTS', default='localhost', cast=Csv())
 CORS_ALLOW_ALL_ORIGINS = config('CORS_ALLOW_ALL_ORIGINS', default=True, cast=bool)
 CORS_URLS_REGEX = config('CORS_URLS_REGEX', default=r'^(?:/api/artifacts/.*|/media/artifacts/.*)$')
 CORS_ALLOW_METHODS = config('CORS_ALLOW_METHODS', default='GET, OPTIONS', cast=Csv())
+CSRF_TRUSTED_ORIGINS = config('CSRF_TRUSTED_ORIGINS', default='', cast=Csv())
 CSP_DEFAULT_SRC = config(
     'CSP_DEFAULT_SRC',
     cast=lambda v: tuple(s.strip() for s in v.split(',')),
@@ -430,10 +441,6 @@ CSP_WORKER_SRC = config(
 CSP_CHILD_SRC = config(
     'CSP_CHILD_SRC', cast=lambda v: tuple(s.strip() for s in v.split(',')), default='blob:'
 )
-SECURE_HSTS_INCLUDE_SUBDOMAINS = True
-SECURE_CONTENT_TYPE_NOSNIFF = True
-SECURE_BROWSER_XSS_FILTER = True
-ALLOWED_HOSTS = config('ALLOWED_HOSTS', default='localhost', cast=Csv())
 
 # Database
 DATABASE_URL = config('DATABASE_URL', default='sqlite:///db.sqlite3')
