@@ -1,9 +1,8 @@
 """ Base Django URL mapping for SatNOGS DB"""
 from allauth import urls as allauth_urls
 from django.conf import settings
-from django.conf.urls import include
 from django.contrib import admin
-from django.urls import path
+from django.urls import include, path
 from django.views.static import serve
 from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerSplitView
 
